@@ -1,7 +1,7 @@
 package Catalyst::Plugin::Sitemap;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Sitemap support for Catalyst.
-$Catalyst::Plugin::Sitemap::VERSION = '1.0.2';
+$Catalyst::Plugin::Sitemap::VERSION = '1.0.3';
 use strict;
 use warnings;
 
@@ -10,7 +10,6 @@ use Moose::Role;
 no warnings qw/uninitialized/;
 
 use WWW::Sitemap::XML;
-use List::Util qw/ first /;
 
 has sitemap => (
     is      => 'ro',
@@ -84,7 +83,7 @@ Catalyst::Plugin::Sitemap - Sitemap support for Catalyst.
 
 =head1 VERSION
 
-version 1.0.2
+version 1.0.3
 
 =head1 SYNOPSIS
 
@@ -93,47 +92,47 @@ version 1.0.2
     use Catalyst qw/ Sitemap /;
 
     # in the controller
-    
-    sub alone :Local :Sitemap { 
-        ... 
+
+    sub alone :Local :Sitemap {
+        ...
     }
-    
+
     sub with_priority :Local :Sitemap(0.75) {
-        ... 
+        ...
     }
-    
+
     sub with_args :Local
             :Sitemap( lastmod => 2010-09-27, changefreq => daily ) {
         ...
     }
-    
-    sub with_function :Local :Sitemap(*) { 
-        ... 
+
+    sub with_function :Local :Sitemap(*) {
+        ...
     }
-    
+
     sub with_function_sitemap {
         $_[2]->add( 'http://localhost/with_function' );
     }
 
     # and then...
-    
+
     sub sitemap : Path('/sitemap') {
         my ( $self, $c ) = @_;
- 
+
         $c->res->body( $c->sitemap_as_xml );
     }
 
 =head1 DESCRIPTION
 
-L<Catalyst::Plugin::Sitemap> provides a way to semi-automate the creation 
+L<Catalyst::Plugin::Sitemap> provides a way to semi-automate the creation
 of the sitemap of a Catalyst application.
 
 =head1 CONTEXT METHOD
 
 =head2 sitemap()
 
-Returns a L<WWW::Sitemap::XML> object. The sitemap object is populated by 
-inspecting the controllers of the application for actions with the 
+Returns a L<WWW::Sitemap::XML> object. The sitemap object is populated by
+inspecting the controllers of the application for actions with the
 sub attribute C<:Sitemap>.
 
 =head2 sitemap_as_xml()
@@ -153,7 +152,7 @@ attribute.  It can be invoked in different ways:
         ...
     }
 
-Adds the url of the action to the sitemap.  
+Adds the url of the action to the sitemap.
 
 If the action does not
 resolves in a single url, this will results in an error.
@@ -186,7 +185,7 @@ resolves in a single url, this will results in an error.
 =item C<:Sitemap(*)>
 
     sub with_function :Local :Sitemap(*) { }
-    
+
     sub with_function_sitemap {
         my ( $self, $c, $sitemap ) = @_;
 
@@ -196,8 +195,8 @@ resolves in a single url, this will results in an error.
 Calls the function 'I<action>_sitemap', if it exists, and passes it the
 controller, context and sitemap objects.
 
-This is currently the only way to invoke C<:Sitemap> on an action 
-resolving to many urls. 
+This is currently the only way to invoke C<:Sitemap> on an action
+resolving to many urls.
 
 =back
 
@@ -216,7 +215,7 @@ Original module that this plugin was using under the hood.
 =item L<Dancer::Plugin::SiteMap>
 
 Similar plugin for the L<Dancer> framework, which inspired
-C<Catalyst::Plugin::Sitemap>. 
+C<Catalyst::Plugin::Sitemap>.
 
 =item L<http://techblog.babyl.ca/entry/catalyst-plugin-sitemap>
 
@@ -230,7 +229,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yanick Champoux.
+This software is copyright (c) 2019, 2015, 2010 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
